;; Generated package description from preview-auto.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "preview-auto" "0.4.2.0.20260205.43257" "Automatic previews in AUCTeX" '((emacs "29.3") (auctex "14.0.5")) :commit "6da4a97bf51a3994525958cfa3736fb80003d4e7" :authors '(("Paul D. Nelson" . "nelson.paul.david@gmail.com")) :maintainer '("Paul D. Nelson" . "nelson.paul.david@gmail.com") :keywords '("tex" "convenience") :url "https://github.com/ultronozm/preview-auto.el")
